@@ -16,7 +16,7 @@
 from .location import CloudRegion, CloudZone
 from .partition import Partition
 from .paths import LocationPath, TopicPath, SubscriptionPath
-from .publish_metadata import PublishMetadata
+from .message_metadata import MessageMetadata
 from .flow_control_settings import FlowControlSettings, DISABLED_FLOW_CONTROL
 
 __all__ = (
@@ -25,7 +25,7 @@ __all__ = (
     "FlowControlSettings",
     "LocationPath",
     "Partition",
-    "PublishMetadata",
+    "MessageMetadata",
     "SubscriptionPath",
     "TopicPath",
 )
