@@ -31,7 +31,7 @@ def publish_with_batch_settings(
     from google.cloud.pubsublite.types import (
         CloudRegion,
         CloudZone,
-        PublishMetadata,
+        MessageMetadata,
         TopicPath,
     )
 
@@ -62,9 +62,9 @@ def publish_with_batch_settings(
             api_future = publisher_client.publish(topic_path, data.encode("utf-8"))
             # result() blocks. To resolve API futures asynchronously, use add_done_callback().
             message_id = api_future.result()
-            publish_metadata = PublishMetadata.decode(message_id)
+            message_metadata = MessageMetadata.decode(message_id)
             print(
-                f"Published {data} to partition {publish_metadata.partition.value} and offset {publish_metadata.cursor.offset}."
+                f"Published {data} to partition {message_metadata.partition.value} and offset {message_metadata.cursor.offset}."
             )
 
     print(
